@@ -1,12 +1,13 @@
 # coding=utf-8
 #
-# This file is part of Hypothesis (https://github.com/DRMacIver/hypothesis)
+# This file is part of Hypothesis, which may be found at
+# https://github.com/HypothesisWorks/hypothesis-python
 #
-# Most of this work is copyright (C) 2013-2015 David R. MacIver
+# Most of this work is copyright (C) 2013-2017 David R. MacIver
 # (david@drmaciver.com), but it contains contributions by others. See
-# https://github.com/DRMacIver/hypothesis/blob/master/CONTRIBUTING.rst for a
-# full list of people who may hold copyright, and consult the git log if you
-# need to determine who owns an individual contribution.
+# CONTRIBUTING.rst for a full list of people who may hold copyright, and
+# consult the git log if you need to determine who owns an individual
+# contribution.
 #
 # This Source Code Form is subject to the terms of the Mozilla Public License,
 # v. 2.0. If a copy of the MPL was not distributed with this file, You can
@@ -22,7 +23,6 @@ import warnings
 class HypothesisException(Exception):
 
     """Generic parent class for exceptions thrown by Hypothesis."""
-    pass
 
 
 class CleanupFailed(HypothesisException):
@@ -34,17 +34,10 @@ class UnsatisfiedAssumption(HypothesisException):
 
     """An internal error raised by assume.
 
-    If yo're seeing this error something has gone wrong.
+    If you're seeing this error something has gone wrong.
 
     """
 
-    def __init__(self, *args, **kwargs):
-        if args or kwargs:
-            super(UnsatisfiedAssumption, self).__init__(*args, **kwargs)
-        else:
-            super(UnsatisfiedAssumption, self).__init__(
-                'Unsatisfied assumption')
-
 
 class BadTemplateDraw(HypothesisException):
 
@@ -74,18 +67,14 @@ class NoSuchExample(HypothesisException):
         )
 
 
-class DefinitelyNoSuchExample(NoSuchExample):
+class DefinitelyNoSuchExample(NoSuchExample):  # pragma: no cover
+    """Hypothesis used to be able to detect exhaustive coverage of a search
+    space and no longer can.
 
-    """We have considered the entire example space available and there are no
-    examples in it."""
+    This exception remains for compatibility reasons for now but can
+    never actually be thrown.
 
-    def __init__(self, condition_string, n_examples):
-        super(DefinitelyNoSuchExample, self).__init__(
-            condition_string, ' (all %d considered)' % (
-                n_examples,
-            )
-        )
-        self.n_examples = n_examples
+    """
 
 
 class NoExamples(HypothesisException):
@@ -93,7 +82,6 @@ class NoExamples(HypothesisException):
     """Raised when example() is called on a strategy but we cannot find any
     examples after enough tries that we really should have been able to if this
     was ever going to work."""
-    pass
 
 
 class Unsatisfiable(HypothesisException):
@@ -113,10 +101,9 @@ class Unsatisfiable(HypothesisException):
 
 class Flaky(HypothesisException):
 
-    """
-    This function appears to fail non-deterministically: We have seen it fail
-    when passed this example at least once, but a subsequent invocation did not
-    fail.
+    """This function appears to fail non-deterministically: We have seen it
+    fail when passed this example at least once, but a subsequent invocation
+    did not fail.
 
     Common causes for this problem are:
         1. The function depends on external state. e.g. it uses an external
@@ -126,7 +113,8 @@ class Flaky(HypothesisException):
            depends sensitively on where it's been called from.
         3. The function is timing sensitive and can fail or pass depending on
            how long it takes. Try breaking it up into smaller functions which
-           dont' do that and testing those instead.
+           don't do that and testing those instead.
+
     """
 
 
@@ -154,6 +142,17 @@ class InvalidArgument(HypothesisException, TypeError):
     some manner incorrect."""
 
 
+class ResolutionFailed(InvalidArgument):
+
+    """Hypothesis had to resolve a type to a strategy, but this failed.
+
+    Type inference is best-effort, so this only happens when an
+    annotation exists but could not be resolved for a required argument
+    to the target of ``builds()``, or where the user passed ``infer``.
+
+    """
+
+
 class InvalidState(HypothesisException):
 
     """The system is not in a state where you were allowed to do that."""
@@ -181,3 +180,14 @@ class HypothesisDeprecationWarning(HypothesisException, DeprecationWarning):
 
 
 warnings.simplefilter('once', HypothesisDeprecationWarning)
+
+
+class Frozen(HypothesisException):
+
+    """Raised when a mutation method has been called on a ConjectureData object
+    after freeze() has been called."""
+
+
+class MultipleFailures(HypothesisException):
+    """Indicates that Hypothesis found more than one distinct bug when testing
+    your code."""
